@@ -275,7 +275,7 @@ class DeltaTable:
         read in the stream to a dataframe
         """
 
-        format = kw.get('cloudFiles.format') or 'csv'
+        format = kw.get('cloudFiles_format') or 'csv'
         header = kw.get('header') or 'true'
         multiline = kw.get('multiLine') or 'true'
         escape = kw.get('escape') or "\""
